|PyPI Version| |Build Status| |Coverage Status| |Python Version|

Yet Another Pika Wrapper (yapw – pronounced yapu) makes it easier to create a `Pika <https://pika.readthedocs.io/en/stable/>`__ client that:

-  Runs consumer callbacks in separate threads.
-  Automatically decodes and encodes messages.
-  Has error handling, signal handling, useful logging and good defaults.

(If you are viewing this on GitHub, open the `full documentation <https://yapw.readthedocs.io/>`__ for additional details.)

.. |PyPI Version| image:: https://img.shields.io/pypi/v/yapw.svg
   :target: https://pypi.org/project/yapw/
.. |Build Status| image:: https://github.com/open-contracting/yapw/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/open-contracting/yapw/actions/workflows/ci.yml
.. |Coverage Status| image:: https://codecov.io/github/open-contracting/yapw/graph/badge.svg
   :target: https://codecov.io/github/open-contracting/yapw
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/yapw.svg
   :target: https://pypi.org/project/yapw/
